Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(918)

Unified Diff: chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h

Issue 2954293002: Chromad: Prevent session from starting without policy (Closed)
Patch Set: Comment fixes Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h
diff --git a/chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h b/chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h
index 1aff35985614116e4e362eed4324f07b821f1f0f..a22f951a545c209f6131a8777c4e69eefb44a30d 100644
--- a/chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h
+++ b/chrome/browser/chromeos/policy/user_cloud_policy_manager_chromeos.h
@@ -131,15 +131,15 @@ class UserCloudPolicyManagerChromeOS : public CloudPolicyManager,
// successful.
void OnInitialPolicyFetchComplete(bool success);
- // Called when |policy_fetch_timeout_| times out, to cancel the blocking
- // wait for the initial policy fetch.
+ // Called when |policy_fetch_timeout_| times out, to cancel the blocking wait
+ // for the initial policy fetch.
void OnBlockingFetchTimeout();
// Cancels waiting for the policy fetch and flags the
// ConfigurationPolicyProvider ready (assuming all other initialization tasks
- // have completed). Pass |true| if policy fetch was successful (either
- // because policy was successfully fetched, or if DMServer has notified us
- // that the user is not managed).
+ // have completed). Pass |true| if policy fetch was successful (either because
+ // policy was successfully fetched, or if DMServer has notified us that the
+ // user is not managed).
void CancelWaitForPolicyFetch(bool success);
void StartRefreshSchedulerIfReady();
@@ -156,18 +156,18 @@ class UserCloudPolicyManagerChromeOS : public CloudPolicyManager,
// Path where policy for components will be cached.
base::FilePath component_policy_cache_path_;
// Whether to wait for a policy fetch to complete before reporting
// IsInitializationComplete().
- bool wait_for_policy_fetch_;
+ bool waiting_for_initial_policy_fetch_;
- // Whether we should allow policy fetches to fail, or wait forever until they
- // succeed (typically we won't allow them to fail until we have loaded policy
- // at least once).
- bool allow_failed_policy_fetches_;
+ // Whether the user session is continued in case of failure of initial policy
+ // fetch.
+ bool initial_policy_fetch_may_fail_;
// A timer that puts a hard limit on the maximum time to wait for the initial
// policy fetch.
- base::Timer policy_fetch_timeout_{false, false};
+ base::Timer policy_fetch_timeout_{false /* retain_user_task */,
emaxx 2017/07/12 20:18:20 (just note) Thanks for doing this cleanup!
+ false /* is_repeating */};
// The pref service to pass to the refresh scheduler on initialization.
PrefService* local_state_;
@@ -131,15 +131,15 @@ class UserCloudPolicyManagerChromeOS : public CloudPolicyManager,
void OnBlockingFetchTimeout();
- // Cancels waiting for the policy fetch and flags the
+ // Cancels waiting for the initial policy fetch and flags the
// ConfigurationPolicyProvider ready (assuming all other initialization tasks
@@ -156,18 +156,18 @@ class UserCloudPolicyManagerChromeOS : public CloudPolicyManager,
// Path where policy for components will be cached.
base::FilePath component_policy_cache_path_;
- // Whether to wait for a policy fetch to complete before reporting
+ // Whether we're waiting for a policy fetch to complete before reporting
// IsInitializationComplete().

Powered by Google App Engine
This is Rietveld 408576698